@@ -9,7 +9,10 @@
 #' @param cc1.postbomb Use \code{postbomb=TRUE} to get a postbomb calibration curve for cc1 (default \code{cc1.postbomb=FALSE}).
 #' @param cc2.postbomb Use \code{postbomb=TRUE} to get a postbomb calibration curve for cc2 (default \code{cc2.postbomb=FALSE}).
 #' @param BCAD The calendar scale of graphs and age output-files is in cal BP (calendar or calibrated years before the present, where the present is AD 1950) by default, but can be changed to BC/AD using \code{BCAD=TRUE}.
-#' @param realm Which 'realm' of radiocarbon to use. Defaults to \code{realm="C14"} but can also be set to \code{realm="F14C"}, \code{realm="pMC"} or \code{realm="D14C"}. Can be shorted to, respectively, "C", "F", "P" or "D" (or their lower-case equivalents).
+#' @param realm Which 'realm' of radiocarbon to use. Defaults to \code{realm="C14"} but can also be set to \code{realm="F14C"}, \code{realm="pMC"} or \code{realm="D14C"}. Can be shorted to, respectively, "C", "F", "P" or "D" (or their lower-case equivalents). Alternatively, the realm can be defined using `as.F=TRUE`, `as.pMC=TRUE` or `as.D=TRUE`.
+#' @param as.F Plot as F14C values. Defaults to \code{as.F=FALSE}.
+#' @param as.pMC Plot as pMC values. Defaults to \code{as.pMC=FALSE}.
+#' @param as.D Plot as D14C values. Defaults to \code{as.D=FALSE}.
 #' @param realm2 Which 'realm' to use for the second calibration curve (if used). Defaults to \code{realm="C14"} but can also be set to \code{realm="F14C"}, \code{realm="pMC"} or \code{realm="D14C"}. Can be shorted to, respectively, "C", "F", "P" or "D" (or their lower-case equivalents).
 #' @param cal.lab The labels for the calendar axis (default \code{age.lab="cal BP"} or \code{"BC/AD"} if \code{BCAD=TRUE}), or to \code{age.lab="kcal BP"} etc. if ka=TRUE.
 #' @param cal.rev Reverse the calendar axis. 
@@ -22,7 +25,7 @@
 #' @param cc1.fill Colour of the calibration curve (fill).
 #' @param cc2.col Colour of the calibration curve (outline), if activated (default cc2=NA).
 #' @param cc2.fill Colour of the calibration curve (fill), if activated (default cc2=NA).
-#' @param add Whether or not to add the curve(s) to an existing plot. Defaults to FALSE, which draws a new plot
+#' @param add Whether or not to add the curve(s) to an existing plot. Defaults to FALSE, which draws a new plot.
 #' @param bty Draw a box around a box of a certain shape. Defaults to \code{bty="l"}.
 #' @param cc.dir Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., \code{cc.dir="curves"}.
 #' @param legend Location of the legend (only activated if more than one curve is plotted). Plotted in the topleft corner by default. Use \code{legend=c()} to leave empty
@@ -33,17 +36,30 @@
 #' draw.ccurve(1800, 2020, BCAD=TRUE, cc2="nh1", cc2.postbomb=TRUE)
 #' draw.ccurve(1800, 2010, BCAD=TRUE, cc2="nh1", add.yaxis=TRUE)
 #' @export
-draw.ccurve <- function(cal1=c(), cal2=c(), cc1="IntCal20", cc2=NA, cc1.postbomb=FALSE, cc2.postbomb=FALSE, BCAD=FALSE, realm="C14", realm2=c(), cal.lab=NA, cal.rev=FALSE, c14.lab=NA, c14.lim=NA, c14.rev=FALSE, ka=FALSE, add.yaxis=FALSE, cc1.col=rgb(0,0,1,.5), cc1.fill=rgb(0,0,1,.2), cc2.col=rgb(0,.5,0,.5), cc2.fill=rgb(0,.5,0,.2), add=FALSE, bty="l", cc.dir=NULL, legend="topleft", ...) {
+draw.ccurve <- function(cal1=c(), cal2=c(), cc1="IntCal20", cc2=NA, cc1.postbomb=FALSE, cc2.postbomb=FALSE, BCAD=FALSE, realm="C14", as.F=FALSE, as.pMC=FALSE, as.D=FALSE, realm2=c(), cal.lab=NA, cal.rev=FALSE, c14.lab=NA, c14.lim=NA, c14.rev=FALSE, ka=FALSE, add.yaxis=FALSE, cc1.col=rgb(0,0,1,.5), cc1.fill=rgb(0,0,1,.2), cc2.col=rgb(0,.5,0,.5), cc2.fill=rgb(0,.5,0,.2), add=FALSE, bty="l", cc.dir=NULL, legend="topleft", ...) {
+
+  # checking realm
+  if(sum(as.F, as.pMC, as.D) > 1)
+    stop("only one of as.F, as.pMC or as.D can be set to TRUE")
+  if(sum(as.F, as.pMC, as.D) > 0) {
+    if(as.F) realm <- "f"
+    if(as.pMC) realm <- "p"
+    if(as.D) realm <- "d"
+  } else {
+    if(grepl("^f", tolower(realm))) as.F <- TRUE
+    if(grepl("^p", tolower(realm))) as.pMC <- TRUE
+    if(grepl("^d", tolower(realm))) as.D <- TRUE
+  }
 
   # read and narrow down the calibration curve(s)
   if(cc1 %in% c(2, "Marine20")) # then no postbomb curve available
-    cc.1 <- rintcal::ccurve(2, postbomb=FALSE, cc.dir) else
+    cc.1 <- rintcal::ccurve(2, postbomb=FALSE, cc.dir=cc.dir, as.F=as.F, as.pMC=as.pMC, as.D=as.D) else
       if(cc1.postbomb)
-        cc.1 <- rintcal::glue.ccurves(cc1, cc1.postbomb, cc.dir) else
-          cc.1 <- rintcal::ccurve(cc1, cc1.postbomb, cc.dir)
+        cc.1 <- rintcal::glue.ccurves(cc1, postbomb=cc1.postbomb, cc.dir=cc.dir, as.F=as.F, as.pMC=as.pMC) else
+          cc.1 <- rintcal::ccurve(cc1, postbomb=cc1.postbomb, cc.dir=cc.dir, as.F=as.F, as.pMC=as.pMC, as.D=as.D)
   cc.cal <- 1 # which column to use for calendar ages
   if(BCAD) {
-    cc.1[,4] <- 1950 - cc.1[,1] # add a column...
+    cc.1[,4] <- calBPtoBCAD(cc.1[,1]) # add a column...
     cc.cal <- 4 # ... and use it
   }
   if(length(cal1) == 0)
@@ -57,30 +73,17 @@ draw.ccurve <- function(cal1=c(), cal2=c(), cc1="IntCal20", cc2=NA, cc1.postbomb
 
   if(ka) {
     cc.1[,1] <- cc.1[,1]/1e3
-    if(grepl("c", tolower(realm)))  # ka doesn't make sense for F14C, pMC, or D14C
+    if(grepl("c", tolower(realm)) && sum(as.F, as.pMC, as.D) == 0)  # ka doesn't make sense for F14C, pMC, or D14C
       cc.1[,2:3] <- cc.1[,2:3]/1e3
   }
 
-  if(grepl("f", tolower(realm))) {
-    F <- C14toF14C(cc.1[,2], cc.1[,3])
-    cc.1[,2:3] <- F
-  }
-  if(grepl("p", tolower(realm))) {
-    p <- C14topMC(cc.1[,2], cc.1[,3])
-    cc.1[,2:3] <- p
-  }
-  if(grepl("d", tolower(realm))) {
-    asD <- C14toD14C(cc.1[,2], cc.1[,3], cc.1[,1])
-    cc.1[,2:3] <- cbind(asD)
-  }
- 
   cc1.pol <- cbind(c(cc.1[,cc.cal], rev(cc.1[,cc.cal])), c(cc.1[,2]-cc.1[,3], rev(cc.1[,2]+cc.1[,3])))
   
   if(!is.na(cc2)) {
     if(length(realm2) == 0)
       realm2 <- realm
     if(cc2.postbomb)
-      cc.2 <- rintcal::glue.ccurves(cc2, cc2.postbomb, cc.dir) else
+      cc.2 <- rintcal::glue.ccurves(prebomb=cc1, postbomb=cc2.postbomb, cc.dir=cc.dir) else 
         cc.2 <- rintcal::ccurve(cc2, cc2.postbomb, cc.dir)
     if(BCAD) 
       cc.2[,4] <- 1950 - cc.2[,1] 
@@ -89,7 +92,7 @@ draw.ccurve <- function(cal1=c(), cal2=c(), cc1="IntCal20", cc2=NA, cc1.postbomb
 
     if(ka) {
       cc.2[,1] <- cc.2[,1]/1e3
-      if(grepl("c", tolower(realm2)))  # ka doesn't make sense for F14C, pMC, or D14C
+      if(grepl("c", tolower(realm2))) # ka doesn't make sense for F14C, pMC, or D14C
         cc.2[,2:3] <- cc.2[,2:3]/1e3
     }
     if(grepl("f", tolower(realm2))) {
@@ -288,7 +291,7 @@ draw.ccurve <- function(cal1=c(), cal2=c(), cc1="IntCal20", cc2=NA, cc1.postbomb
 #' @param bty Draw a box around the graph ("n" for none, and "l", "7", "c", "u", "]" or "o" for correspondingly shaped boxes).
 #' @param cc.dir Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., \code{cc.dir="curves"}.
 #' @param cc.er The error of the calibration curve. Only used for plotting the uncalibrated C14 distribution, which by default only shows the date's uncertainty (the calibration curve uncertainty is indeed taken into account during calibration). If known, the calibration curve's error can be added.
-#' @param every Yearly precision (defaults to \code{every=1}).
+#' @param every Not used, use yr.steps instead.
 #' @param ... Other plotting parameters.
 #' @return A graph of the raw and calibrated C-14 date, the calibrated ranges and, invisibly, the calibrated distribution and hpd ranges.
 #' @examples
@@ -358,8 +361,10 @@ calibrate <- function(age=2450, error=50, cc=1, postbomb=FALSE, deltaR=0, deltaS
       if(is.F)
         asF <- c(age, error) else
           asF <- C14toF14C(age, error)
-  if(asF[1] < (2*asF[2])) { # according to background conventions
-    msg <- "age < (2*er) in F14C space; this date is at background and should NOT be calibrated!"
+    # maxcc <- rintcal::ccurve(cc, postbomb=postbomb, cc.dir, as.F=TRUE)
+    # maxcc <- maxcc[nrow(maxcc),2:3]
+    if(asF[1] < (2*asF[2])) { # according to background conventions
+    msg <- paste("age < (2*er) in F14C space; this date is at background and should NOT be calibrated!")
     if(edge)
       stop(msg) else
         message(msg)
@@ -386,7 +391,7 @@ calibrate <- function(age=2450, error=50, cc=1, postbomb=FALSE, deltaR=0, deltaS
 
   C14.dist <- caldist(age, sqrt(error^2 + cc.er^2), cc=0, BCAD=FALSE, postbomb=FALSE) # just to draw a normal dist
   cal.dist <- caldist(age, error, cc=cc, yrsteps=yr.steps, threshold=threshold,
-  normal=normal, is.F=is.F, as.F=as.F, t.a=t.a, t.b=t.b, postbomb=postbomb, cc.dir=cc.dir, BCAD=BCAD)
+  normal=normal, is.F=is.F, is.pMC=is.pMC, as.F=as.F, t.a=t.a, t.b=t.b, postbomb=postbomb, cc.dir=cc.dir, BCAD=BCAD)
 
   # copy entries at edges of calibrated hpds, to ensure rectangular polygons
   if(draw) {
@@ -401,11 +406,10 @@ calibrate <- function(age=2450, error=50, cc=1, postbomb=FALSE, deltaR=0, deltaS
     if(cal.rev)
       cal.lim <- rev(cal.lim)
     }  
-
     if(length(C14.lim) == 0) {
       if(BCAD) {
-        cc.min <- max(1, min(which(Cc[,4] <= max(cal.lim))))
-        cc.max <- min(nrow(Cc), max(which(Cc[,4] >= min(cal.lim))))
+        cc.min <- max(1, min(which(Cc[,cc.cal] <= max(cal.lim))))
+        cc.max <- min(nrow(Cc), max(which(Cc[,cc.cal] >= min(cal.lim))))
       } else {  
           cc.min <- max(1, min(which(Cc[,1] >= min(cal.lim))))
           cc.max <- min(nrow(Cc), max(which(Cc[,1] <= max(cal.lim))))
@@ -496,7 +500,7 @@ draw.dist <- function(dist, on.y=FALSE, rotate.axes=FALSE, mirror=FALSE, up=TRUE
   # which direction to draw the distribution(s)
   xy <- par('usr')
   if(on.y) {
-	leftright <- fraction*(xy[2] - xy[1]) # from left to right corner
+    leftright <- fraction*(xy[2] - xy[1]) # from left to right corner
     if(as.unit)
       leftright <- ifelse(leftright >= 0, 1, -1)
     add <- ifelse(up, 1, -1)*ex*leftright
